@@ -29,6 +29,7 @@
 #include "workspace.h"
 #include "application.h"
 #include "xutils.h"
+#include "pager.h"
 
 G_BEGIN_DECLS
 
@@ -47,7 +48,8 @@ WnckWindow* _wnck_window_create  (Window      xwindow,
                                   WnckScreen *screen);
 void        _wnck_window_destroy (WnckWindow *window);
 
-WnckWorkspace* _wnck_workspace_create  (int            number);
+WnckWorkspace* _wnck_workspace_create  (int            number,
+					WnckScreen    *screen);
 void           _wnck_workspace_destroy (WnckWorkspace *space);
 
 void _wnck_window_set_application    (WnckWindow      *window,
@@ -71,6 +73,22 @@ void _wnck_init (void);
 #define DEFAULT_MINI_ICON_WIDTH 16
 #define DEFAULT_MINI_ICON_HEIGHT 16
 
+#define WNCK_SCREEN_XSCREEN(screen) (_wnck_screen_get_xscreen (screen))
+
+Screen *_wnck_screen_get_xscreen (WnckScreen *screen);
+
+
+void           _wnck_pager_activate_workspace   (WnckWorkspace *wspace);
+int            _wnck_pager_get_n_workspaces     (WnckPager     *pager);
+const char*    _wnck_pager_get_workspace_name   (WnckPager     *pager,
+                                                 int            i);
+WnckWorkspace* _wnck_pager_get_active_workspace (WnckPager     *pager);
+WnckWorkspace* _wnck_pager_get_workspace        (WnckPager     *pager,
+                                                 int            i);
+void           _wnck_pager_get_workspace_rect   (WnckPager     *pager,
+                                                 int            i,
+                                                 GdkRectangle  *rect);
+
 G_END_DECLS
 
 #endif /* WNCK_PRIVATE_H */
