@@ -79,16 +79,21 @@ guint _wnck_xid_hash  (gconstpointer v);
 void _wnck_iconify   (Window xwindow);
 void _wnck_deiconify (Window xwindow);
 
-void _wnck_close     (Window xwindow);
+void _wnck_close     (Screen *screen,
+		      Window  xwindow);
 
-void _wnck_change_state     (Window   xwindow,
+void _wnck_change_state     (Screen  *screen,
+			     Window   xwindow,
                              gboolean add,
                              Atom     state1,
                              Atom     state2);
-void _wnck_change_workspace (Window   xwindow,
+void _wnck_change_workspace (Screen  *screen,
+			     Window   xwindow,
                              int      new_space);
-void _wnck_activate         (Window   xwindow);
-void _wnck_activate_workspace (int    new_active_space);
+void _wnck_activate         (Screen  *screen,
+			     Window   xwindow);
+void _wnck_activate_workspace (Screen *screen,
+			       int     new_active_space);
 
 Window _wnck_get_group_leader   (Window xwindow);
 char*  _wnck_get_session_id     (Window xwindow);
@@ -99,6 +104,12 @@ char*  _wnck_get_res_class_utf8 (Window xwindow);
 void   _wnck_select_input     (Window xwindow,
                                int    mask);
 
+void   _wnck_keyboard_move    (Screen *screen,
+                               Window  xwindow);
+
+void   _wnck_keyboard_size    (Screen *screen,
+                               Window  xwindow);
+
 typedef struct _WnckIconCache WnckIconCache;
 
 WnckIconCache *_wnck_icon_cache_new                  (void);
@@ -127,15 +138,17 @@ void _wnck_get_fallback_icons (GdkPixbuf     **iconp,
 
 
 
-void _wnck_get_window_geometry (Window xwindow,
-                                int   *xp,
-                                int   *yp,
-                                int   *widthp,
-                                int   *heightp);
+void _wnck_get_window_geometry (Screen *screen,
+				Window  xwindow,
+                                int    *xp,
+                                int    *yp,
+                                int    *widthp,
+                                int    *heightp);
 
-void _wnck_get_window_position (Window xwindow,
-                                int   *xp,
-                                int   *yp);
+void _wnck_get_window_position (Screen *screen,
+				Window  xwindow,
+                                int    *xp,
+                                int    *yp);
 
 void _wnck_set_icon_geometry  (Window xwindow,
 			       int    x,
@@ -145,6 +158,10 @@ void _wnck_set_icon_geometry  (Window xwindow,
 
 void _wnck_set_dock_type_hint (Window xwindow);
 
+void _wnck_set_desktop_layout (Screen *xscreen,
+                               int     rows,
+                               int     columns);
+
 GdkPixbuf* _wnck_gdk_pixbuf_get_from_pixmap (GdkPixbuf   *dest,
                                              Pixmap       xpixmap,
                                              int          src_x,
@@ -154,6 +171,14 @@ GdkPixbuf* _wnck_gdk_pixbuf_get_from_pixmap (GdkPixbuf   *dest,
                                              int          width,
                                              int          height);
 
+#define WNCK_NO_MANAGER_TOKEN 0
+
+int      _wnck_try_desktop_layout_manager           (Screen *xscreen,
+                                                     int     current_token);
+void     _wnck_release_desktop_layout_manager       (Screen *xscreen,
+                                                     int     current_token);
+gboolean _wnck_desktop_layout_manager_process_event (XEvent *xev);
+
 G_END_DECLS
 
 #endif /* WNCK_XUTILS_H */
